function [pi, alpha, theta] = ccgStruct_wrapper(counts, E, W)

% Function for train a ccg on a vector of count
% The initialization of the model is done automatically with complete link
% clustering. One can be also initialize pi (theta) randomly.
% N.B. E must be divisible by W(1)^2 for this initialization to work.

eq_no_t = round( prod(E) / prod(W) );

% pi initialization
Z = linkage(counts, 'complete');
C = cluster(Z, 'maxclust', eq_no_t);

pi_init = zeros(size(counts,1), eq_no_t);
for i = 1:eq_no_t
    pi_init(C == i, i) = 1;
end
pi_init = normalize(pi_init,1);
pi_init(pi_init==0) = 1/(size(pi_init,1));
eq_E = [ceil(sqrt(eq_no_t)) ceil(sqrt(eq_no_t))];
for i = 1:size(pi_init,1)
    init(:,:,i) = reshape(pi_init(i,:),eq_E);
end
init = bsxfun(@rdivide, init, sum(init,3));
init = expandcg(init, E, W);

% theta initialization
Z = linkage(counts', 'complete');
C = cluster(Z, 'maxclust', eq_no_t);
theta_init = zeros(eq_no_t, size(counts,2));
for i = 1:eq_no_t
    theta_init(i,C == i) = 1;
end
theta_init = normalize(theta_init,1);
theta_init(theta_init==0) = 1/(size(theta_init,1));
theta_init = normalize(theta_init,1);
eq_E = [round(sqrt(eq_no_t)) round(sqrt(eq_no_t))];
for i = 1:size(theta_init,2)
    tinit(:,:,i) = reshape(theta_init(:,i),eq_E);
end
tinit = expandcg(tinit, E, W);
tinit = bsxfun(@rdivide, tinit, sum(sum(tinit,2),1));
tinit = reshape(tinit, [size(tinit,1)*size(tinit,2) size(tinit,3)]);

% Set options
clear options

options.pi = init;
options.learn_pi = 1;
options.max_iter = 60;
options.learn_alpha = 0;
options.theta = tinit;

% Learn the model
[pi,alpha,theta] = ccg(counts, E, W, options);